==> jc-1.4.0.tar.gz: javax/security/auth/SubjectDomainCombiner.h <==
// public class javax.security.auth.SubjectDomainCombiner

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33bfb490d7dca084 javax_security_auth_SubjectDomainCombiner

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_SubjectDomainCombiner_H_
#define _JC_javax_security_auth_SubjectDomainCombiner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_security_auth_Subject$object;

// Typedefs
typedef struct _jc_javax_security_auth_SubjectDomainCombiner$sub_refs	_jc_javax_security_auth_SubjectDomainCombiner$sub_refs;
typedef struct _jc_javax_security_auth_SubjectDomainCombiner$sub_nonrefs	_jc_javax_security_auth_SubjectDomainCombiner$sub_nonrefs;
typedef struct _jc_javax_security_auth_SubjectDomainCombiner$refs	_jc_javax_security_auth_SubjectDomainCombiner$refs;
typedef struct _jc_javax_security_auth_SubjectDomainCombiner$nonrefs	_jc_javax_security_auth_SubjectDomainCombiner$nonrefs;
typedef struct _jc_javax_security_auth_SubjectDomainCombiner$object	_jc_javax_security_auth_SubjectDomainCombiner$object;

typedef const struct _jc_javax_security_auth_SubjectDomainCombiner$vmethods	_jc_javax_security_auth_SubjectDomainCombiner$vmethods;
typedef const struct _jc_javax_security_auth_SubjectDomainCombiner$vtable	_jc_javax_security_auth_SubjectDomainCombiner$vtable;
typedef const struct _jc_javax_security_auth_SubjectDomainCombiner$vtype	_jc_javax_security_auth_SubjectDomainCombiner$vtype;

// Constructors
extern void _jc_javax_security_auth_SubjectDomainCombiner$method$_init$1c3f0a49fd3c6034(_jc_env *, struct _jc_javax_security_auth_SubjectDomainCombiner$object *, struct _jc_javax_security_auth_Subject$object *);

// Virtual methods
extern _jc_object_array *_jc_javax_security_auth_SubjectDomainCombiner$method$combine$f9648237767d4f5a(_jc_env *, struct _jc_javax_security_auth_SubjectDomainCombiner$object *, struct _jc_object_array *, struct _jc_object_array *);
extern struct _jc_javax_security_auth_Subject$object *_jc_javax_security_auth_SubjectDomainCombiner$method$getSubject$7db516660a3ff3c7(_jc_env *, struct _jc_javax_security_auth_SubjectDomainCombiner$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_SubjectDomainCombiner$method_info$combine$f9648237767d4f5a;
extern _jc_method _jc_javax_security_auth_SubjectDomainCombiner$method_info$getSubject$7db516660a3ff3c7;

// Virtual methods structure
struct _jc_javax_security_auth_SubjectDomainCombiner$vmethods {
	_jc_object_array	*(*combine$f9648237767d4f5a)(_jc_env *, struct _jc_javax_security_auth_SubjectDomainCombiner$object *, struct _jc_object_array *, struct _jc_object_array *);
	struct _jc_javax_security_auth_Subject$object	*(*getSubject$7db516660a3ff3c7)(_jc_env *, struct _jc_javax_security_auth_SubjectDomainCombiner$object *);
};

// Vtable
struct _jc_javax_security_auth_SubjectDomainCombiner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_SubjectDomainCombiner$vmethods	javax_security_auth_SubjectDomainCombiner;
};

// Vtype
struct _jc_javax_security_auth_SubjectDomainCombiner$vtype {
	_jc_type			type;
	_jc_javax_security_auth_SubjectDomainCombiner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_SubjectDomainCombiner$sub_refs {
	struct _jc_javax_security_auth_Subject$object	*subject;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_SubjectDomainCombiner$refs {
    _jc_javax_security_auth_SubjectDomainCombiner$sub_refs	javax_security_auth_SubjectDomainCombiner;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_SubjectDomainCombiner$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_SubjectDomainCombiner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_SubjectDomainCombiner$sub_nonrefs	javax_security_auth_SubjectDomainCombiner;
};

// Object instance structure
struct _jc_javax_security_auth_SubjectDomainCombiner$object {
	_jc_javax_security_auth_SubjectDomainCombiner$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_SubjectDomainCombiner$vtype	*vtype;
	_jc_javax_security_auth_SubjectDomainCombiner$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_SubjectDomainCombiner$vtype _jc_javax_security_auth_SubjectDomainCombiner$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_SubjectDomainCombiner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_SubjectDomainCombiner$class_object;

#endif	/* _JC_javax_security_auth_SubjectDomainCombiner_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/SubjectDomainCombiner.h <==
// public class javax.security.auth.SubjectDomainCombiner

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 33bfb490d7dca084 javax_security_auth_SubjectDomainCombiner

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_SubjectDomainCombiner_H_
#define _JC_javax_security_auth_SubjectDomainCombiner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_security_auth_Subject$object;

// Typedefs
typedef struct _jc_javax_security_auth_SubjectDomainCombiner$sub_refs	_jc_javax_security_auth_SubjectDomainCombiner$sub_refs;
typedef struct _jc_javax_security_auth_SubjectDomainCombiner$sub_nonrefs	_jc_javax_security_auth_SubjectDomainCombiner$sub_nonrefs;
typedef struct _jc_javax_security_auth_SubjectDomainCombiner$refs	_jc_javax_security_auth_SubjectDomainCombiner$refs;
typedef struct _jc_javax_security_auth_SubjectDomainCombiner$nonrefs	_jc_javax_security_auth_SubjectDomainCombiner$nonrefs;
typedef struct _jc_javax_security_auth_SubjectDomainCombiner$object	_jc_javax_security_auth_SubjectDomainCombiner$object;

typedef const struct _jc_javax_security_auth_SubjectDomainCombiner$vmethods	_jc_javax_security_auth_SubjectDomainCombiner$vmethods;
typedef const struct _jc_javax_security_auth_SubjectDomainCombiner$vtable	_jc_javax_security_auth_SubjectDomainCombiner$vtable;
typedef const struct _jc_javax_security_auth_SubjectDomainCombiner$vtype	_jc_javax_security_auth_SubjectDomainCombiner$vtype;

// Constructors
extern void _jc_javax_security_auth_SubjectDomainCombiner$method$_init$1c3f0a49fd3c6034(_jc_env *, struct _jc_javax_security_auth_SubjectDomainCombiner$object *, struct _jc_javax_security_auth_Subject$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_javax_security_auth_SubjectDomainCombiner$method$combine$f9648237767d4f5a(_jc_env *, struct _jc_javax_security_auth_SubjectDomainCombiner$object *, struct _jc_object_array *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_javax_security_auth_Subject$object *_jc_javax_security_auth_SubjectDomainCombiner$method$getSubject$7db516660a3ff3c7(_jc_env *, struct _jc_javax_security_auth_SubjectDomainCombiner$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_SubjectDomainCombiner$method_info$combine$f9648237767d4f5a;
extern _jc_method _jc_javax_security_auth_SubjectDomainCombiner$method_info$getSubject$7db516660a3ff3c7;

// Virtual methods structure
struct _jc_javax_security_auth_SubjectDomainCombiner$vmethods {
	_jc_object_array	*(*combine$f9648237767d4f5a)(_jc_env *, struct _jc_javax_security_auth_SubjectDomainCombiner$object *, struct _jc_object_array *, struct _jc_object_array *) _JC_JCNI_ATTR;
	struct _jc_javax_security_auth_Subject$object	*(*getSubject$7db516660a3ff3c7)(_jc_env *, struct _jc_javax_security_auth_SubjectDomainCombiner$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_SubjectDomainCombiner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_SubjectDomainCombiner$vmethods	javax_security_auth_SubjectDomainCombiner;
};

// Vtype
struct _jc_javax_security_auth_SubjectDomainCombiner$vtype {
	_jc_type			type;
	_jc_javax_security_auth_SubjectDomainCombiner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_SubjectDomainCombiner$sub_refs {
	struct _jc_javax_security_auth_Subject$object	*subject;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_SubjectDomainCombiner$refs {
    _jc_javax_security_auth_SubjectDomainCombiner$sub_refs	javax_security_auth_SubjectDomainCombiner;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_SubjectDomainCombiner$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_SubjectDomainCombiner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_SubjectDomainCombiner$sub_nonrefs	javax_security_auth_SubjectDomainCombiner;
};

// Object instance structure
struct _jc_javax_security_auth_SubjectDomainCombiner$object {
	_jc_javax_security_auth_SubjectDomainCombiner$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_SubjectDomainCombiner$vtype	*vtype;
	_jc_javax_security_auth_SubjectDomainCombiner$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_SubjectDomainCombiner$vtype _jc_javax_security_auth_SubjectDomainCombiner$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_SubjectDomainCombiner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_SubjectDomainCombiner$class_object;

#endif	/* _JC_javax_security_auth_SubjectDomainCombiner_H_ */
